bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.plot
============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.plot